@@ -5,7 +5,7 @@
  *
  * Copyright (c) 2000 Dug Song <dugsong@monkey.org>
  *
- * $Id: ip.h,v 1.18 2002/01/30 00:12:55 dugsong Exp $
+ * $Id: ip.h,v 1.20 2002/04/02 05:05:39 dugsong Exp $
  */
 
 #ifndef DNET_IP_H
@@ -34,6 +34,8 @@ struct ip_hdr {
 #elif DNET_BYTESEX == DNET_LIL_ENDIAN
 	uint8_t		ip_hl:4,
 			ip_v:4;
+#else
+# error "need to include <dnet.h>"	
 #endif
 	uint8_t		ip_tos;		/* type of service */
 	uint16_t	ip_len;		/* total length (incl header) */
@@ -396,13 +398,13 @@ struct ip_opt {
 #define IP_ADDR_MCAST_ALL	(htonl(0xe0000001))	/* 224.0.0.1 */
 #define IP_ADDR_MCAST_LOCAL	(htonl(0xe00000ff))	/* 224.0.0.225 */
 
-#define ip_fill_hdr(hdr, tos, len, id, off, ttl, p, src, dst) do {	\
-	struct ip_hdr *ip_fill_p = (struct ip_hdr *)(hdr);		\
-	ip_fill_p->ip_v = 4; ip_fill_p->ip_hl = 5;			\
-	ip_fill_p->ip_tos = tos; ip_fill_p->ip_len = htons(len);	\
- 	ip_fill_p->ip_id = htons(id); ip_fill_p->ip_off = htons(off);	\
-	ip_fill_p->ip_ttl = ttl; ip_fill_p->ip_p = p;			\
-	ip_fill_p->ip_src = src; ip_fill_p->ip_dst = dst;		\
+#define ip_pack_hdr(hdr, tos, len, id, off, ttl, p, src, dst) do {	\
+	struct ip_hdr *ip_pack_p = (struct ip_hdr *)(hdr);		\
+	ip_pack_p->ip_v = 4; ip_pack_p->ip_hl = 5;			\
+	ip_pack_p->ip_tos = tos; ip_pack_p->ip_len = htons(len);	\
+ 	ip_pack_p->ip_id = htons(id); ip_pack_p->ip_off = htons(off);	\
+	ip_pack_p->ip_ttl = ttl; ip_pack_p->ip_p = p;			\
+	ip_pack_p->ip_src = src; ip_pack_p->ip_dst = dst;		\
 } while (0)
 
 typedef struct ip_handle ip_t;
